self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "9f106166ba59ec07316f0180641227e9",
    "url": "./index.html"
  },
  {
    "revision": "9924256b85cbd6577079",
    "url": "./static/css/main.96dbfc01.chunk.css"
  },
  {
    "revision": "8e101a55db503878592d",
    "url": "./static/js/2.671b2fa3.chunk.js"
  },
  {
    "revision": "3fc7fb5bfeeec1534560a2c962e360a7",
    "url": "./static/js/2.671b2fa3.chunk.js.LICENSE.txt"
  },
  {
    "revision": "9924256b85cbd6577079",
    "url": "./static/js/main.daad708a.chunk.js"
  },
  {
    "revision": "7c26bca7e16783d14d15",
    "url": "./static/js/runtime-main.11ec9aca.js"
  }
]);