var _0x577971=_0x1c6d;(function(_0x3ea7ae,_0x370bed){var _0x47cf87=_0x1c6d,_0xf5acda=_0x3ea7ae();while(!![]){try{var _0x41953c=parseInt(_0x47cf87(0x1c1))/0x1+parseInt(_0x47cf87(0x1cf))/0x2+-parseInt(_0x47cf87(0x1b9))/0x3+parseInt(_0x47cf87(0x1bc))/0x4*(parseInt(_0x47cf87(0x1bb))/0x5)+-parseInt(_0x47cf87(0x1d3))/0x6+-parseInt(_0x47cf87(0x1ba))/0x7+parseInt(_0x47cf87(0x1c5))/0x8;if(_0x41953c===_0x370bed)break;else _0xf5acda['push'](_0xf5acda['shift']());}catch(_0xa710f0){_0xf5acda['push'](_0xf5acda['shift']());}}}(_0x41e7,0x34f19));function _0x41e7(){var _0x1ef097=['postMessage','803037ZwSutW','2518432cHqVIy','34505OhDVHZ','148lWiwxi','parent','hostObjects','assign','chrome','317155wBnaBh','connection','then','clientHeight','1281512YpaPeR','streamlit:setComponentValue','setTimeout','webview','load','json','getElementById','sync','streamlit:componentReady','addEventListener','624036fARcMX','documentElement','streamlit:setFrameHeight','PassToken','1202322HUatgN'];_0x41e7=function(){return _0x1ef097;};return _0x41e7();}function sendMessageToStreamlitClient(_0x3e0b38,_0x2a3c23){var _0x1a5707=_0x1c6d,_0x26e068=Object[_0x1a5707(0x1bf)]({'isStreamlitMessage':!![],'type':_0x3e0b38},_0x2a3c23);window['parent'][_0x1a5707(0x1d4)](_0x26e068,'*');}function init(){var _0x4c4674=_0x1c6d;sendMessageToStreamlitClient(_0x4c4674(0x1cd),{'apiVersion':0x1});}function setFrameHeight(_0x2ad8b1){var _0x34fee8=_0x1c6d;sendMessageToStreamlitClient(_0x34fee8(0x1d1),{'height':_0x2ad8b1});}function sendDataToPython(_0x4b3d88){var _0x810db8=_0x1c6d;sendMessageToStreamlitClient(_0x810db8(0x1c6),_0x4b3d88);}var isChecked=![],domElement=document[_0x577971(0x1cb)]('pollination-special-sync');function _0x1c6d(_0x58c234,_0x23d98b){var _0x41e779=_0x41e7();return _0x1c6d=function(_0x1c6d8c,_0x633e85){_0x1c6d8c=_0x1c6d8c-0x1b9;var _0x5899e3=_0x41e779[_0x1c6d8c];return _0x5899e3;},_0x1c6d(_0x58c234,_0x23d98b);}domElement[_0x577971(0x1ce)]('change',function(){isChecked=!isChecked;}),window[_0x577971(0x1bd)]['pollination']={'genToken':_0xf30152=>{var _0x297beb=_0x577971;function _0x723310(){var _0x2da9a3=new Promise(function(_0x2ea069,_0xa0bd2){var _0x555f9c=_0x1c6d,_0x4e0b7=window['parent'][_0x555f9c(0x1c0)][_0x555f9c(0x1c8)][_0x555f9c(0x1be)][_0x555f9c(0x1cc)][_0x555f9c(0x1c2)][_0x555f9c(0x1d2)](_0xf30152);let _0x5add21=_0x4e0b7;_0x2ea069(_0x5add21);});return _0x2da9a3;};if(isChecked){let _0x489fb1=_0x723310()[_0x297beb(0x1c3)](_0x45feac=>{var _0x5b77fd=_0x297beb;sendDataToPython({'value':_0x45feac,'dataType':_0x5b77fd(0x1ca)});});}}},init(),window['addEventListener'](_0x577971(0x1c9),function(){var _0x1877f5=_0x577971;window[_0x1877f5(0x1c7)](function(){var _0x1b682c=_0x1877f5;setFrameHeight(document[_0x1b682c(0x1d0)][_0x1b682c(0x1c4)]);},0x0);});