.poCheckboxLabel {
  font-family: "Source Sans Pro", sans-serif;
  display: inline-block;
  padding-right: 10px;
  white-space: nowrap;
}

.poCheckboxSpan {
  vertical-align: middle;
}

.poCheckbox {
	/* Font & Text */
	font-size: 16px;
	font-style: normal;
	font-variant: normal;
	font-weight: 400;
	letter-spacing: normal;
	line-height: 25.6px;
	text-decoration: none solid rgb(49, 51, 63);
	text-align: start;
	text-indent: 0px;
	text-transform: none;
	vertical-align: middle;
	white-space: normal;
	word-spacing: 0px;

	/* Color & Background */
	background-attachment: scroll;
	background-color: rgb(249, 249, 251);
	background-image: none;
	background-position: 50% 50%;
	background-repeat: no-repeat;
	color: rgb(49, 51, 63);

	/* Box */
	height: 20px;
	width: 20px;
	margin-right: 4px;
	border: 2px solid rgba(49, 51, 63, 0.4);
	border-top: 2px solid rgba(49, 51, 63, 0.4);
	border-right: 2px solid rgba(49, 51, 63, 0.4);
	border-bottom: 2px solid rgba(49, 51, 63, 0.4);
	min-width: auto;

	/* Positioning */
	position: static;
	top: 4px;
	bottom: auto;
	right: auto;
	left: 4px;
	float: none;
	display: inline-flex;
	clear: none;
	z-index: auto;

	/* List */
	list-style-image: none;
	list-style-type: disc;
	list-style-position: outside;

	/* Table */
	border-collapse: separate;
	border-spacing: 0px 0px;
	caption-side: top;
	empty-cells: show;
	table-layout: auto;

	/* Miscellaneous */
	overflow: visible;
	cursor: pointer;
	visibility: visible;

	/* Effects */
	transform: none;
	outline-offset: 0px;
	box-sizing: border-box;
	resize: none;
	text-shadow: none;
	text-overflow: clip;
	word-wrap: normal;
	box-shadow: none;
	border-top-left-radius: 4px;
	border-top-right-radius: 4px;
	border-bottom-left-radius: 4px;
	border-bottom-right-radius: 4px;
}