(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{17:function(n,t,e){n.exports={poButton:"style_poButton__3x8Ka"}},18:function(n,t,e){n.exports=e(26)},26:function(n,t,e){"use strict";e.r(t);var o=e(8),a=e.n(o),c=e(15),r=e.n(c),i=e(6),s=e(0),m=e(1),l=e(2),u=e(3),p=e(13),d=e(17),f=e.n(d),g=function(n){Object(l.a)(e,n);var t=Object(u.a)(e);function e(){var n;Object(m.a)(this,e);for(var o=arguments.length,c=new Array(o),r=0;r<o;r++)c[r]=arguments[r];return(n=t.call.apply(t,[this].concat(c))).state={action:"RunCommand",commandString:"",commandOptions:"",isFocused:!1},n.render=function(){return a.a.createElement("span",null,a.a.createElement("button",{className:f.a.poButton,onClick:n.onClicked,disabled:n.props.disabled,onFocus:n._onFocus,onBlur:n._onBlur},a.a.createElement("span",null,a.a.createElement("img",{style:{margin:"0px 3px 2px 0px"},src:"./img/pollination.png",alt:"logo"})),"Run Command"))},n.onClicked=function(){if("undefined"!=typeof window.parent.chrome){if("undefined"==typeof window.parent.chrome.webview)return void console.log("[POLLINATION-DEBUG]: webview not found.");var t={action:"RunCommand",commandString:n.props.args.commandString,commandOptions:n.props.args.commandOptions},e=JSON.stringify(t);window.parent.chrome.webview.postMessage(e),n.setState((function(n){return Object(i.a)(Object(i.a)({},n),{},{action:t.action,commandString:t.commandString,commandOptions:t.commandOptions})}),(function(){return p.a.setComponentValue(n.state.action)})),console.log("[POLLINATION-DEBUG]: JSON string sent.")}else console.log("[POLLINATION-DEBUG]: chrome not found.")},n._onFocus=function(){n.setState({isFocused:!0})},n._onBlur=function(){n.setState({isFocused:!1})},n}return Object(s.a)(e)}(p.b),O=Object(p.c)(g);r.a.render(a.a.createElement(a.a.StrictMode,null,a.a.createElement(O,null)),document.getElementById("root"))}},[[18,1,2]]]);
//# sourceMappingURL=main.205cae2d.chunk.js.map